@@ -17,7 +17,7 @@ local({
   context("Unitize")
 
   update_fastlm(.unitizer.fastlm, "0.1.0")
-  devtools::install(.unitizer.fastlm, quick=TRUE, quiet=TRUE, local=FALSE)
+  install.packages(.unitizer.fastlm, repos=NULL, type='src', quiet=TRUE)
   test.dir <- file.path(.unitizer.fastlm, "tests", "unitizer")
   unlink(.unitizer.test.store, recursive=TRUE)
 
@@ -308,7 +308,7 @@ local({
   # Update `fastlm` to cause unitizers to fail, and go through the errors
 
   update_fastlm(.unitizer.fastlm, version="0.1.1")
-  devtools::install(.unitizer.fastlm, quick=TRUE, quiet=TRUE, local=FALSE)
+  install.packages(.unitizer.fastlm, repos=NULL, type='src', quiet=TRUE)
 
   # Try navigating through the unitizer
 
@@ -440,7 +440,7 @@ local({
   # Upgrade again, and try with deleted tests and other things
 
   update_fastlm(.unitizer.fastlm, version="0.1.2")
-  devtools::install(.unitizer.fastlm, quick=TRUE, quiet=TRUE, local=FALSE)
+  install.packages(.unitizer.fastlm, repos=NULL, type='src', quiet=TRUE)
   unitizer:::read_line_set_vals(
     c("3", "ref(res)", "Y", "Y", "B", "1", "B", "U", "Y", "RR", "Y", "Q")
   )
